@@ -1,4 +1,4 @@
-# $Id: maxstat.test.R 372 2003-08-30 14:29:45Z hothorn $
+# $Id: maxstat.test.R 413 2015-01-19 17:27:25Z hothorn $
 
 maxstat.test <- function(formula, data, ...) 
   UseMethod("maxstat.test", data)
@@ -160,7 +160,7 @@ cmaxstat <- function(y, x=NULL, weights = NULL,
   if (minprop == 0 & maxprop==1) m <- m[2:(length(m)-1)] else {
     if (all(m < floor(N*minprop))) stop("minprop too large")
     if (all(m > floor(N*maxprop))) stop("maxprop too small")
-    m <- m[m >= floor(N*minprop)]
+    m <- m[m >= max(1, floor(N*minprop))]
     m <- m[m <= floor(N*maxprop)]
   }
 
